kdiagram.plot.evaluation.plot\_polar\_confusion\_multiclass
===========================================================

.. currentmodule:: kdiagram.plot.evaluation

.. autofunction:: plot_polar_confusion_multiclass